@@ -17,9 +17,9 @@
 #include "config.h"
 
 #include "gswitchit-applet.h"
-#include "libgswitchit/gswitchit-config.h"
-#include "libgswitchit/gswitchit-util.h"
-#include "libkbdraw/keyboard-drawing.h"
+#include <libgnomekbd/gkbd-desktop-config.h>
+#include <libgnomekbd/gkbd-util.h>
+#include <libgnomekbd/gkbd-keyboard-drawing.h>
 
 #include <string.h>
 #include <sys/types.h>
@@ -31,8 +31,12 @@
 #include <gdk/gdkscreen.h>
 #include <gdk/gdkx.h>
 #include <glade/glade.h>
+#include <libgnomeui/gnome-help.h>
 
 #define GROUPS_SUBMENU_PATH "/popups/popup/groups"
+#define PLUGINS_CAPPLET_EXECUTABLE "gkbd-indicator-plugins-capplet"
+
+#define GTK_RESPONSE_PRINT 2
 
 /* we never build applet without XKB, so far: TODO */
 #define HAVE_XKB  1
@@ -94,6 +98,7 @@ static void GSwitchItAppletUpdateBackground (GSwitchItApplet * sia);
 
 static const BonoboUIVerb gswitchitAppletMenuVerbs[] = {
 	BONOBO_UI_UNSAFE_VERB ("Capplet", GSwitchItAppletCmdCapplet),
+	BONOBO_UI_UNSAFE_VERB ("Plugins", GSwitchItAppletCmdPlugins),
 	BONOBO_UI_UNSAFE_VERB ("Preview", GSwitchItAppletCmdPreview),
 	BONOBO_UI_UNSAFE_VERB ("About", GSwitchItAppletCmdAbout),
 	BONOBO_UI_UNSAFE_VERB ("Help", GSwitchItAppletCmdHelp),
@@ -101,7 +106,7 @@ static const BonoboUIVerb gswitchitAppletMenuVerbs[] = {
 };
 
 void
-GSwitchItAppletReinitUi (GnomeKbdIndicator * gki, GSwitchItApplet * sia)
+GSwitchItAppletReinitUi (GkbdIndicator * gki, GSwitchItApplet * sia)
 {
 	GSwitchItAppletCleanupGroupsSubmenu (sia);
 	GSwitchItAppletSetupGroupsSubmenu (sia);
@@ -112,7 +117,7 @@ static void
 GSwitchItAppletChangePixelSize (PanelApplet *
 				widget, guint size, GSwitchItApplet * sia)
 {
-	gnome_kbd_indicator_reinit_ui (GNOME_KBD_INDICATOR (sia->gki));
+	gkbd_indicator_reinit_ui (GKBD_INDICATOR (sia->gki));
 }
 
 static void
@@ -128,9 +133,8 @@ GSwitchitAppletUpdateAngle (GSwitchItApplet * sia,
 	case PANEL_APPLET_ORIENT_RIGHT:
 		angle = orient == PANEL_APPLET_ORIENT_LEFT ? 270 : 90;
 	}
-	gnome_kbd_indicator_set_angle (GNOME_KBD_INDICATOR (sia->gki),
-				       angle);
-	gnome_kbd_indicator_reinit_ui (GNOME_KBD_INDICATOR (sia->gki));
+	gkbd_indicator_set_angle (GKBD_INDICATOR (sia->gki), angle);
+	gkbd_indicator_reinit_ui (GKBD_INDICATOR (sia->gki));
 }
 
 static void
@@ -219,7 +223,9 @@ GSwitchItAppletCmdCapplet (BonoboUIComponent *
 					  &error);
 
 	if (error != NULL) {
-		/* FIXME: After string ui freeze are over, we want to show an error message here */
+		g_warning
+		    ("Could not execute keyboard properties capplet: [%s]\n",
+		     error->message);
 		g_error_free (error);
 	}
 }
@@ -228,18 +234,34 @@ static void
 GSwitchItPreviewResponse (GtkWidget * dialog, gint resp)
 {
 	GdkRectangle rect;
+	GtkWidget *kbdraw;
+	const gchar *groupName;
 
 	switch (resp) {
 	case GTK_RESPONSE_HELP:
-		gswitchit_help (GTK_WIDGET (dialog), "layout-view");
+		gnome_help_display_on_screen ("gswitchit", "layout-view",
+					      gtk_widget_get_screen
+					      (dialog), NULL);
 		return;
 	case GTK_RESPONSE_CLOSE:
 		gtk_window_get_position (GTK_WINDOW (dialog), &rect.x,
 					 &rect.y);
 		gtk_window_get_size (GTK_WINDOW (dialog), &rect.width,
 				     &rect.height);
-		gswitchit_preview_save_position (&rect);
+		gkbd_preview_save_position (&rect);
 		gtk_widget_destroy (dialog);
+		break;
+	case GTK_RESPONSE_PRINT:
+		kbdraw =
+		    GTK_WIDGET (g_object_get_data
+				(G_OBJECT (dialog), "kbdraw"));
+		groupName =
+		    (const gchar *) g_object_get_data (G_OBJECT (dialog),
+						       "groupName");
+		gkbd_keyboard_drawing_print (GKBD_KEYBOARD_DRAWING
+					     (kbdraw), GTK_WINDOW (dialog),
+					     groupName ? groupName :
+					     _("Unknown"));
 	}
 }
 
@@ -258,9 +280,15 @@ void
 GSwitchItAppletCmdPreview (BonoboUIComponent *
 			   uic, GSwitchItApplet * sia, const gchar * verb)
 {
-	static KeyboardDrawingGroupLevel groupsLevels[] =
-	    { {0, 1}, {0, 3}, {0, 0}, {0, 2} };
-	static KeyboardDrawingGroupLevel *pGroupsLevels[] = {
+	static GkbdKeyboardDrawingGroupLevel groupsLevels[] = { {
+								 0, 1}, {
+									 0,
+									 3},
+	{
+	 0, 0}, {
+		 0, 2}
+	};
+	static GkbdKeyboardDrawingGroupLevel *pGroupsLevels[] = {
 		groupsLevels, groupsLevels + 1, groupsLevels + 2,
 		groupsLevels + 3
 	};
@@ -271,9 +299,9 @@ GSwitchItAppletCmdPreview (BonoboUIComponent *
 	XklConfigRec *xklData;
 	GdkRectangle *rect;
 #endif
-	XklEngine *engine = gnome_kbd_indicator_get_xkl_engine ();
+	XklEngine *engine = gkbd_indicator_get_xkl_engine ();
 	XklState *xklState = xkl_engine_get_current_state (engine);
-	gchar **groupNames = gnome_kbd_indicator_get_group_names ();
+	gchar **groupNames = gkbd_indicator_get_group_names ();
 	gpointer p = g_hash_table_lookup (globals.previewDialogs,
 					  GINT_TO_POINTER (xklState->
 							   group));
@@ -287,19 +315,23 @@ GSwitchItAppletCmdPreview (BonoboUIComponent *
 	    glade_xml_new (GNOME_GLADEDIR "/gswitchit.glade",
 			   "gswitchit_layout_view", NULL);
 	dialog = glade_xml_get_widget (gladeData, "gswitchit_layout_view");
-	kbdraw = keyboard_drawing_new ();
+	kbdraw = gkbd_keyboard_drawing_new ();
 
 	if (xklState->group >= 0 &&
 	    xklState->group < g_strv_length (groupNames)) {
-		char title[128];
+		char title[128] = "";
 		snprintf (title, sizeof (title),
 			  _("Keyboard Layout \"%s\""),
 			  groupNames[xklState->group]);
 		gtk_window_set_title (GTK_WINDOW (dialog), title);
+		g_object_set_data_full (G_OBJECT (dialog), "groupName",
+					g_strdup (groupNames
+						  [xklState->group]),
+					g_free);
 	}
 
-	keyboard_drawing_set_groups_levels (KEYBOARD_DRAWING (kbdraw),
-					    pGroupsLevels);
+	gkbd_keyboard_drawing_set_groups_levels (GKBD_KEYBOARD_DRAWING
+						 (kbdraw), pGroupsLevels);
 
 	xklData = xkl_config_rec_new ();
 	if (xkl_config_rec_get_from_server (xklData, engine)) {
@@ -336,9 +368,9 @@ GSwitchItAppletCmdPreview (BonoboUIComponent *
 
 		if (xkl_xkb_config_native_prepare
 		    (engine, xklData, &componentNames)) {
-			keyboard_drawing_set_keyboard (KEYBOARD_DRAWING
-						       (kbdraw),
-						       &componentNames);
+			gkbd_keyboard_drawing_set_keyboard
+			    (GKBD_KEYBOARD_DRAWING (kbdraw),
+			     &componentNames);
 			xkl_xkb_config_native_cleanup (engine,
 						       &componentNames);
 		}
@@ -352,7 +384,7 @@ GSwitchItAppletCmdPreview (BonoboUIComponent *
 	g_signal_connect (G_OBJECT (dialog), "response",
 			  G_CALLBACK (GSwitchItPreviewResponse), NULL);
 
-	rect = gswitchit_preview_load_position ();
+	rect = gkbd_preview_load_position ();
 	if (rect != NULL) {
 		gtk_window_move (GTK_WINDOW (dialog), rect->x, rect->y);
 		gtk_window_resize (GTK_WINDOW (dialog), rect->width,
@@ -367,6 +399,8 @@ GSwitchItAppletCmdPreview (BonoboUIComponent *
 			   (glade_xml_get_widget
 			    (gladeData, "preview_vbox")), kbdraw);
 
+	gtk_object_set_data (GTK_OBJECT (dialog), "kbdraw", kbdraw);
+
 	g_hash_table_insert (globals.previewDialogs,
 			     GINT_TO_POINTER (xklState->group), dialog);
 
@@ -374,12 +408,29 @@ GSwitchItAppletCmdPreview (BonoboUIComponent *
 #endif
 }
 
+void
+GSwitchItAppletCmdPlugins (BonoboUIComponent *
+			   uic, GSwitchItApplet * sia, const gchar * verb)
+{
+	GError *error = NULL;
+
+	gdk_spawn_command_line_on_screen (gtk_widget_get_screen
+					  (GTK_WIDGET (sia->applet)),
+					  PLUGINS_CAPPLET_EXECUTABLE,
+					  &error);
+
+	if (error != NULL) {
+		g_warning ("Could not execute plugins capplet: [%s]\n",
+			   error->message);
+		g_error_free (error);
+	}
+}
 static void
 GSwitchItAppletCmdSetGroup (BonoboUIComponent
 			    * uic, GSwitchItApplet * sia,
 			    const gchar * verb)
 {
-	XklEngine *engine = gnome_kbd_indicator_get_xkl_engine ();
+	XklEngine *engine = gkbd_indicator_get_xkl_engine ();
 	XklState st;
 	Window cur;
 	if (sscanf (verb, "Group_%d", &st.group) != 1) {
@@ -409,27 +460,23 @@ void
 GSwitchItAppletCmdHelp (BonoboUIComponent
 			* uic, GSwitchItApplet * sia, const gchar * verb)
 {
-	gswitchit_help (GTK_WIDGET (sia->applet), NULL);
-}
-
-void
+	gnome_help_display_on_screen ("gswitchit", NULL,
+				      gtk_widget_get_screen (sia->applet),
+				      NULL);
+} void
 GSwitchItAppletCmdAbout (BonoboUIComponent *
 			 uic, GSwitchItApplet * sia, const gchar * verb)
 {
 	const gchar *authors[] = {
-		"Sergey V. Udaltsov<svu@gnome.org>",
-		NULL
+		"Sergey V. Udaltsov<svu@gnome.org>", NULL
 	};
 	const gchar *documenters[] = {
-		"Sergey V. Udaltsov<svu@gnome.org>",
-		NULL
+		"Sergey V. Udaltsov<svu@gnome.org>", NULL
 	};
 
 	const gchar *translator_credits = _("translator-credits");
 
-	gtk_show_about_dialog (NULL,
-			       "name", _("Keyboard Indicator"),
-			       "version", VERSION,
+	gtk_show_about_dialog (NULL, "version", VERSION,
 /* Translators: Please replace (C) with the proper copyright character. */
 			       "copyright",
 			       _
@@ -472,7 +519,7 @@ static void
 GSwitchItAppletSetupGroupsSubmenu (GSwitchItApplet * sia)
 {
 	unsigned i;
-	gchar **currentName = gnome_kbd_indicator_get_group_names ();
+	gchar **currentName = gkbd_indicator_get_group_names ();
 	BonoboUIComponent *popup;
 	popup =
 	    panel_applet_get_popup_component (PANEL_APPLET (sia->applet));
@@ -480,14 +527,14 @@ GSwitchItAppletSetupGroupsSubmenu (GSwitchItApplet * sia)
 	for (i = 0; *currentName; i++, currentName++) {
 		char verb[40];
 		BonoboUINode *node;
+		gchar *imageFile;
 		g_snprintf (verb, sizeof (verb), "Group_%d", i);
 		node = bonobo_ui_node_new ("menuitem");
 		bonobo_ui_node_set_attr (node, "name", verb);
 		bonobo_ui_node_set_attr (node, "verb", verb);
 		bonobo_ui_node_set_attr (node, "label", *currentName);
 		bonobo_ui_node_set_attr (node, "pixtype", "filename");
-		gchar *imageFile =
-		    gnome_kbd_indicator_get_image_filename (i);
+		imageFile = gkbd_indicator_get_image_filename (i);
 		if (imageFile != NULL) {
 			bonobo_ui_node_set_attr (node, "pixname",
 						 imageFile);
@@ -508,7 +555,9 @@ static void
 GSwitchItAppletSetupMenu (GSwitchItApplet * sia)
 {
 	BonoboUIComponent *popup;
-	XklEngine *engine = gnome_kbd_indicator_get_xkl_engine ();
+	gchar *pluginsCappletFullPath =
+	    g_find_program_in_path (PLUGINS_CAPPLET_EXECUTABLE);
+	XklEngine *engine = gkbd_indicator_get_xkl_engine ();
 	const char *engine_backend_name =
 	    xkl_engine_get_backend_name (engine);
 
@@ -527,6 +576,13 @@ GSwitchItAppletSetupMenu (GSwitchItApplet * sia)
 						    engine_backend_name) ?
 				      "0" : "1", NULL);
 
+	/* Delete the plugins item if the binary does not exist */
+	if (pluginsCappletFullPath == NULL)
+		bonobo_ui_component_rm (popup,
+					"/popups/popup/Plugins", NULL);
+	else
+		g_free (pluginsCappletFullPath);
+
 	GSwitchItAppletSetupGroupsSubmenu (sia);
 }
 
@@ -542,14 +598,15 @@ GSwitchItAppletInit (GSwitchItApplet * sia, PanelApplet * applet)
 	xkl_debug (100, "Starting the applet startup process for %p\n",
 		   sia);
 
-	glade_gnome_init ();
+	g_set_application_name (_("Keyboard Indicator"));
+
 	gtk_window_set_default_icon_name ("gswitchit-applet");
 
 	sia->applet = GTK_WIDGET (applet);
 
 	panel_applet_set_flags (applet, PANEL_APPLET_EXPAND_MINOR);
 
-	sia->gki = gnome_kbd_indicator_new ();
+	sia->gki = gkbd_indicator_new ();
 
 	orient = panel_applet_get_orient (applet);
 	GSwitchitAppletUpdateAngle (sia, orient);
@@ -557,16 +614,15 @@ GSwitchItAppletInit (GSwitchItApplet * sia, PanelApplet * applet)
 	gtk_container_add (GTK_CONTAINER (sia->applet),
 			   GTK_WIDGET (sia->gki));
 
-	gnome_kbd_indicator_set_tooltips_format (_
-						 ("Keyboard Indicator (%s)"));
-	gnome_kbd_indicator_set_parent_tooltips (GNOME_KBD_INDICATOR
-						 (sia->gki), TRUE);
+	gkbd_indicator_set_tooltips_format (_("Keyboard Indicator (%s)"));
+	gkbd_indicator_set_parent_tooltips (GKBD_INDICATOR
+					    (sia->gki), TRUE);
 
 
 	gtk_widget_show_all (sia->applet);
 	gtk_widget_realize (sia->applet);
 
-	max_ratio = gnome_kbd_indicator_get_max_width_height_ratio ();
+	max_ratio = gkbd_indicator_get_max_width_height_ratio ();
 
 	if (max_ratio > 0) {
 		switch (orient) {
