@@ -132,50 +132,30 @@ gboolean applet_focus_cb(GtkWidget *widget, GdkEventFocus *event, StickyNotesApp
 	return FALSE;
 }
 
-/* Applet Callback : Save all sticky notes. */
-gboolean applet_save_cb(StickyNotesApplet *applet)
-{
-	stickynotes_save();
-
-	return TRUE;
+static GdkFilterReturn desktop_window_event_filter (GdkXEvent *xevent,
+						    GdkEvent  *event,
+						    gpointer   data)
+{ 
+	if ((((XEvent*)xevent)->xany.type == PropertyNotify) &&
+	    (((XEvent*)xevent)->xproperty.atom == gdk_x11_get_xatom_by_name ("_NET_WM_USER_TIME"))) { 
+		stickynote_show_notes (FALSE);
+	} 
+	return GDK_FILTER_CONTINUE;
 }
 
-/* Applet Callback : Click on the desktop background */
-gboolean applet_check_click_on_desktop_cb(gpointer data)
+void install_check_click_on_desktop (void)
 {
-	static gboolean first_time = TRUE;
-	static Display *dpy;
 	Window desktop_window;
-	char *name;
-	XEvent event;
-
-	if (first_time) {
-		dpy = XOpenDisplay (NULL);
-		first_time = FALSE;
-	}
+	GdkWindow *window;
 
 	if (!get_desktop_window (&desktop_window)) {
-		return TRUE;
+		return;
 	}
-	/* X does not let us monitor mouse clicks in two applications
-	 * so we look at the PropertyChange event which is also fired
-	 * at every click on the desktop */
-	XSelectInput(dpy, desktop_window, PropertyChangeMask);
 
-	if (XCheckWindowEvent(dpy, desktop_window, PropertyChangeMask, &event) == True) {
-		XPropertyEvent *property_event;
-		property_event = (XPropertyEvent*) &event;
-		name = XGetAtomName (dpy, property_event->atom);
+	window = gdk_window_foreign_new (desktop_window);
+	gdk_window_set_events (window, GDK_PROPERTY_CHANGE_MASK);
 
-		if ((property_event->state == PropertyNewValue) && (strcmp (name, "_NET_WM_USER_TIME") == 0)) { 
-			stickynote_show_notes (FALSE);
-		} 
-
-		if (name) {
-			XFree (name);
-		}
-	}
-	return TRUE;
+	gdk_window_add_filter (window, desktop_window_event_filter, NULL);
 }
 
 /* Applet Callback : Change the panel orientation. */
@@ -255,9 +235,6 @@ void applet_destroy_cb (PanelApplet *panel_applet, StickyNotesApplet *applet)
 	if (applet->destroy_all_dialog != NULL)
 		gtk_widget_destroy (applet->destroy_all_dialog);
 
-	if (applet->about_dialog != NULL)
-		gtk_widget_destroy (applet->about_dialog);
-	
 	if (stickynotes->applets != NULL)
 		stickynotes->applets = g_list_remove (stickynotes->applets, applet);
 		
@@ -381,7 +358,6 @@ menu_about_cb (BonoboUIComponent *uic,
 	};
 
 	gtk_show_about_dialog (NULL,
-		"name",		_("Sticky Notes"),
 		"version",	VERSION,
 		"copyright",	"\xC2\xA9 2002-2003 Loban A Rahman, "
 				"\xC2\xA9 2005 Davyd Madeley",
